/**
 * Title: 		  Record 
 * Description:	  Model class wrapping the input HTTP POST Json payload  
 * Copyright:     Copyright (c) 2016
 * Company:       Morpheus Quality Technologies
 * Creation date: 2016-05-01
 * Last modified: 2016-05-10
 * @author 		  Stefano Adriani
 * @version 	  1.0
 */

package model;

import org.codehaus.jackson.annotate.JsonAutoDetect;

/**
 * <strong>SAMPLE CLASS</strong> (optional).<br/><br/>
 *
 * This class is not strictly necessary. It's shipped with this project just to provide a complete
 * example of how to convert a string Json payload into a Java model object (this class).
 * In order to remove this class it's necessary also to remove all references to this 
 * class from the XML Mule's flow. For example:<br/><br/>
 * 
 * <code>&lt;json:json-to-object-transformer doc:name="Convert to Java object" returnClass="model.Record"/&gt;</code><br/><br/>
 * 
 * Moreover, this class is handy when the connection to the database is not available and we want to 
 * test the flow emulating the database with a Java HashMap object (see the "innerMap" bean in the XML flow).<br/>
 * In such scenario we store the payload (converted into this model class) into an HashMap, and since we want
 * to offer a full setters/getters API we store this model object into the HashMap, instead of an ordinary
 * "rough" Java Object.<br/><br/>
 *
 * <strong>Remark</strong>: to stress what stated above, this class is NOT necessary to implement a simple REST service
 * with MuleSoftESB. In fact, in this example, this class is used only to log the object content using:<br/><br/>
 * 
 * <code>&lt;logger message="PostFlow - Request (obj): #[message.payloadAs(model.Record)]" level="INFO" doc:name="Request (obj)"/&gt;</code><br/><br/>
 * 
 * which triggers execution of the class's <code>toString()</code> method (implemented here). 
 */
@JsonAutoDetect
public class Record {
	
	protected int sex;
	
	protected double i_asr;
	
	protected double m_asr;
	
	protected int m_num;
	
	protected int isocountrycd;
	
	protected int i_num;
	
	protected int cancer;
	
	// **********************************************************************************************************
	// SETTERS / GETTERS (auto-generated)
	// **********************************************************************************************************

	public int getSex() {
		return sex;
	}

	public void setSex(int sex) {
		this.sex = sex;
	}

	public double getI_asr() {
		return i_asr;
	}

	public void setI_asr(double i_asr) {
		this.i_asr = i_asr;
	}

	public double getM_asr() {
		return m_asr;
	}

	public void setM_asr(double m_asr) {
		this.m_asr = m_asr;
	}

	public int getM_num() {
		return m_num;
	}

	public void setM_num(int m_num) {
		this.m_num = m_num;
	}

	public int getIsocountrycd() {
		return isocountrycd;
	}

	public void setIsocountrycd(int isocountrycd) {
		this.isocountrycd = isocountrycd;
	}

	public int getI_num() {
		return i_num;
	}

	public void setI_num(int i_num) {
		this.i_num = i_num;
	}

	public int getCancer() {
		return cancer;
	}

	public void setCancer(int cancer) {
		this.cancer = cancer;
	}

	// **********************************************************************************************************
	// OVERRIDE
	// **********************************************************************************************************

	@Override
	public String toString() {
		return "Record [sex=" + sex + ", i_asr=" + i_asr + ", m_asr=" + m_asr
				+ ", m_num=" + m_num + ", isocountrycd=" + isocountrycd
				+ ", i_num=" + i_num + ", cancer=" + cancer + "]";
	}	
	
} // End of class